@@ -1,48 +1,11 @@
 /*
- * "$Id: image.cxx 1488 2006-05-31 19:00:02Z mike $"
+ * Image handling routines for HTMLDOC, a HTML document processing program.
  *
- *   Image handling routines for HTMLDOC, a HTML document processing program.
+ * Copyright 2011-2017 by Michael R Sweet.
+ * Copyright 1997-2010 by Easy Software Products.  All rights reserved.
  *
- *   Copyright 1997-2005 by Easy Software Products.
- *
- *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "COPYING.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
- *
- *       Attn: ESP Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3142 USA
- *
- *       Voice: (301) 373-9600
- *       EMail: info@easysw.com
- *         WWW: http://www.easysw.com
- *
- * Contents:
- *
- *   gif_read_cmap()      - Read the colormap from a GIF file...
- *   gif_get_block()      - Read a GIF data block...
- *   gif_get_code()       - Get a LZW code from the file...
- *   gif_read_image()     - Read a GIF image stream...
- *   gif_read_lzw()       - Read a byte from the LZW stream...
- *   image_compare()      - Compare two image filenames...
- *   image_copy()         - Copy image files to the destination directory...
- *   image_flush_cache()  - Flush the image cache...
- *   image_getlist()      - Get the list of images that are loaded.
- *   image_load()         - Load an image file from disk...
- *   image_load_bmp()     - Read a BMP image file.
- *   image_load_gif()     - Load a GIF image file...
- *   image_load_jpeg()    - Load a JPEG image file.
- *   image_load_png()     - Load a PNG image file.
- *   image_need_mask()    - Allocate memory for the image mask...
- *   image_set_mask()     - Set a bit in the image mask.
- *   jpeg_error_handler() - Handle JPEG errors by not exiting.
- *   read_word()          - Read a 16-bit unsigned integer.
- *   read_dword()         - Read a 32-bit unsigned integer.
- *   read_long()          - Read a 32-bit signed integer.
+ * This program is free software.  Distribution and use rights are outlined in
+ * the file "COPYING".
  */
 
 /*
@@ -84,7 +47,7 @@ typedef uchar	gif_cmap_t[256][3];
  * Local globals...
  */
 
-static int	num_images = 0,		/* Number of images in cache */
+static size_t	num_images = 0,		/* Number of images in cache */
 		alloc_images = 0;	/* Allocated images */
 static image_t	**images = NULL;	/* Images in cache */
 static int	gif_eof = 0;		/* Did we hit EOF? */
@@ -133,7 +96,7 @@ gif_read_cmap(FILE       *fp,		/* I  - File to read from */
   * Read the colormap...
   */
 
-  if (fread(cmap, 3, ncolors, fp) < (size_t)ncolors)
+  if (fread(cmap, 3, (size_t)ncolors, fp) < (size_t)ncolors)
   {
     progress_error(HD_ERROR_READ_ERROR,
                    "Unable to read GIF colormap: %s", strerror(errno));
@@ -189,7 +152,7 @@ gif_get_block(FILE  *fp,	/* I - File to read from */
   }
   else if (count == 0)
     gif_eof = 1;
-  else if (fread(buf, 1, count, fp) < (size_t)count)
+  else if (fread(buf, 1, (size_t)count, fp) < (size_t)count)
   {
     progress_error(HD_ERROR_READ_ERROR,
                    "Unable to read GIF block of %d bytes: %s", count,
@@ -242,7 +205,7 @@ gif_get_code(FILE *fp,		/* I - File to read from */
     return (0);
   }
 
-  if ((curbit + code_size) >= lastbit)
+  if ((curbit + (unsigned)code_size) >= lastbit)
   {
    /*
     * Don't have enough bits to hold the code...
@@ -290,19 +253,18 @@ gif_get_code(FILE *fp,		/* I - File to read from */
     */
 
     curbit    = (curbit - lastbit) + 8 * last_byte;
-    last_byte += count;
+    last_byte += (unsigned)count;
     lastbit   = last_byte * 8;
   }
 
-  ret = 0;
-  for (ret = 0, i = curbit + code_size - 1, j = code_size;
+  for (ret = 0, i = curbit + (unsigned)code_size - 1, j = (unsigned)code_size;
        j > 0;
        i --, j --)
     ret = (ret << 1) | ((buf[i / 8] & bits[i & 7]) != 0);
 
-  curbit += code_size;
+  curbit += (unsigned)code_size;
 
-  return ret;
+  return (int)ret;
 }
 
 
@@ -330,7 +292,7 @@ gif_read_image(FILE       *fp,		/* I - Input file */
   xpos      = 0;
   ypos      = 0;
   pass      = 0;
-  code_size = getc(fp);
+  code_size = (uchar)getc(fp);
 
   if (gif_read_lzw(fp, 1, code_size) < 0)
     return (-1);
@@ -394,17 +356,17 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
 		code,			/* Current code */
 		incode;			/* Input code */
   static short	fresh = 0,		/* 1 = empty buffers */
-		code_size,		/* Current code size */
-		set_code_size,		/* Initial code size set */
-		max_code,		/* Maximum code used */
-		max_code_size,		/* Maximum code size */
-		firstcode,		/* First code read */
-		oldcode,		/* Last code read */
-		clear_code,		/* Clear code for LZW input */
-		end_code,		/* End code for LZW input */
+		code_size = 0,		/* Current code size */
+		set_code_size = 0,	/* Initial code size set */
+		max_code = 0,		/* Maximum code used */
+		max_code_size = 0,	/* Maximum code size */
+		firstcode = 0,		/* First code read */
+		oldcode = 0,		/* Last code read */
+		clear_code = 0,		/* Clear code for LZW input */
+		end_code = 0,		/* End code for LZW input */
 		table[2][4096],		/* String table */
 		stack[8192],		/* Output stack */
-		*sp;			/* Current stack pointer */
+		*sp = stack;		/* Current stack pointer */
 
 
   if (first_time)
@@ -413,9 +375,9 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
     * Setup LZW state...
     */
 
-    set_code_size = input_code_size;
+    set_code_size = (short)input_code_size;
     code_size     = set_code_size + 1;
-    clear_code    = 1 << set_code_size;
+    clear_code    = (short)(1 << set_code_size);
     end_code      = clear_code + 1;
     max_code_size = 2 * clear_code;
     max_code      = clear_code + 2;
@@ -435,7 +397,7 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
     for (i = 0; i < clear_code; i ++)
     {
       table[0][i] = 0;
-      table[1][i] = i;
+      table[1][i] = (short)i;
     }
 
     for (; i < 4096; i ++)
@@ -450,7 +412,7 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
     fresh = 0;
 
     do
-      firstcode = oldcode = gif_get_code(fp, code_size, 0);
+      firstcode = oldcode = (short)gif_get_code(fp, code_size, 0);
     while (firstcode == clear_code);
 
     return (firstcode);
@@ -466,7 +428,7 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
       for (i = 0; i < clear_code; i ++)
       {
 	table[0][i] = 0;
-	table[1][i] = i;
+	table[1][i] = (short)i;
       }
 
       for (; i < 4096; i ++)
@@ -478,7 +440,7 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
 
       sp = stack;
 
-      firstcode = oldcode = gif_get_code(fp, code_size, 0);
+      firstcode = oldcode = (short)gif_get_code(fp, code_size, 0);
 
       return (firstcode);
     }
@@ -526,7 +488,7 @@ gif_read_lzw(FILE *fp,			/* I - File to read from */
       }
     }
 
-    oldcode = incode;
+    oldcode = (short)incode;
 
     if (sp > stack)
       return (*--sp);
@@ -602,7 +564,7 @@ image_copy(const char *src,		/* I - Source file */
   }
 
   while ((nbytes = fread(buffer, 1, sizeof(buffer), in)) > 0)
-    fwrite(buffer, 1, nbytes, out);
+    fwrite(buffer, 1, (size_t)nbytes, out);
 
   progress_error(HD_ERROR_NONE, "BYTES: %ld", ftell(out));
 
@@ -643,7 +605,7 @@ image_find(const char *filename,/* I - Name of image file */
     strlcpy(key.filename, filename, sizeof(key.filename));
     keyptr = &key;
 
-    match = (image_t **)bsearch(&keyptr, images, num_images, sizeof(image_t *),
+    match = (image_t **)bsearch(&keyptr, images, (size_t)num_images, sizeof(image_t *),
                                 (int (*)(const void *, const void *))image_compare);
     if (match != NULL)
     {
@@ -665,7 +627,7 @@ image_find(const char *filename,/* I - Name of image file */
 void
 image_flush_cache(void)
 {
-  int	i;			/* Looping var */
+  size_t	i;			/* Looping var */
 
 
  /*
@@ -752,7 +714,7 @@ image_load(const char *filename,/* I - Name of image file */
     strlcpy(key.filename, filename, sizeof(key.filename));
     keyptr = &key;
 
-    match = (image_t **)bsearch(&keyptr, images, num_images, sizeof(image_t *),
+    match = (image_t **)bsearch(&keyptr, images, (size_t)num_images, sizeof(image_t *),
                                 (int (*)(const void *, const void *))image_compare);
     if (match != NULL && (!load_data || (*match)->pixels))
     {
@@ -793,7 +755,7 @@ image_load(const char *filename,/* I - Name of image file */
 #ifdef DEBUG
   printf("Header for \"%s\" (%s): \"", filename, realname);
 
-  for (i = 0; i < sizeof(header); i ++)
+  for (i = 0; i < (int)sizeof(header); i ++)
     if (header[i] < ' ' || header[i] >= 127)
       printf("\\x%02X", header[i]);
     else
@@ -801,7 +763,7 @@ image_load(const char *filename,/* I - Name of image file */
 
   puts("\"\n");
 
-  printf("match = %p\n", match);
+  printf("match = %p\n", (void *)match);
 #endif // DEBUG
 
   rewind(fp);
@@ -823,7 +785,7 @@ image_load(const char *filename,/* I - Name of image file */
       {
 	progress_error(HD_ERROR_OUT_OF_MEMORY,
 	               "Unable to allocate memory for %d images - %s",
-                       alloc_images, strerror(errno));
+                       (int)alloc_images, strerror(errno));
 	fclose(fp);
 	return (NULL);
       }
@@ -926,16 +888,16 @@ image_load_bmp(image_t *img,	/* I - Image to load into */
   read_dword(fp);
 
   // Then the bitmap information...
-  info_size        = read_dword(fp);
+  info_size        = (int)read_dword(fp);
   img->width       = read_long(fp);
   img->height      = read_long(fp);
   read_word(fp);
   depth            = read_word(fp);
-  compression      = read_dword(fp);
+  compression      = (int)read_dword(fp);
   read_dword(fp);
   read_long(fp);
   read_long(fp);
-  colors_used      = read_dword(fp);
+  colors_used      = (int)read_dword(fp);
   read_dword(fp);
 
   if (info_size > 40)
@@ -946,7 +908,7 @@ image_load_bmp(image_t *img,	/* I - Image to load into */
   if (colors_used == 0 && depth <= 8)
     colors_used = 1 << depth;
 
-  fread(colormap, colors_used, 4, fp);
+  fread(colormap, (size_t)colors_used, 4, fp);
 
   // Setup image and buffers...
   img->depth  = gray ? 1 : 3;
@@ -960,7 +922,7 @@ image_load_bmp(image_t *img,	/* I - Image to load into */
   if (!load_data)
     return (0);
 
-  img->pixels = (uchar *)malloc(img->width * img->height * img->depth);
+  img->pixels = (uchar *)malloc((size_t)(img->width * img->height * img->depth));
   if (img->pixels == NULL)
     return (-1);
 
@@ -990,7 +952,7 @@ image_load_bmp(image_t *img,	/* I - Image to load into */
           for (x = img->width, bit = 128; x > 0; x --)
 	  {
 	    if (bit == 128)
-	      byte = getc(fp);
+	      byte = (uchar)getc(fp);
 
 	    if (byte & bit)
 	    {
@@ -1230,16 +1192,16 @@ image_load_bmp(image_t *img,	/* I - Image to load into */
 	      temp = getc(fp) * 8;
 	      temp += getc(fp) * 61;
 	      temp += getc(fp) * 31;
-	      *ptr++ = temp / 100;
+	      *ptr++ = (uchar)(temp / 100);
 	    }
 	  }
 	  else
 	  {
             for (x = img->width; x > 0; x --, ptr += 3)
 	    {
-	      ptr[2] = getc(fp);
-	      ptr[1] = getc(fp);
-	      ptr[0] = getc(fp);
+	      ptr[2] = (uchar)getc(fp);
+	      ptr[1] = (uchar)getc(fp);
+	      ptr[0] = (uchar)getc(fp);
 	    }
           }
 
@@ -1302,7 +1264,7 @@ image_load_gif(image_t *img,	/* I - Image pointer */
           return (-1);		/* Early end of file */
 
       case '!' :	/* Extension record */
-          buf[0] = getc(fp);
+          buf[0] = (uchar)getc(fp);
           if (buf[0] == 0xf9)	/* Graphic Control Extension */
           {
             gif_get_block(fp, buf);
@@ -1361,7 +1323,7 @@ image_load_gif(image_t *img,	/* I - Image pointer */
 	  if (!load_data)
 	    return (0);
 
-          img->pixels = (uchar *)malloc(img->width * img->height * img->depth);
+          img->pixels = (uchar *)malloc((size_t)(img->width * img->height * img->depth));
           if (img->pixels == NULL)
             return (-1);
 
@@ -1392,9 +1354,9 @@ image_load_jpeg(image_t *img,	/* I - Image pointer */
   cinfo.err = &jerr;
   jpeg_create_decompress(&cinfo);
   jpeg_stdio_src(&cinfo, fp);
-  jpeg_read_header(&cinfo, 1);
+  jpeg_read_header(&cinfo, (boolean)1);
 
-  cinfo.quantize_colors = 0;
+  cinfo.quantize_colors = FALSE;
 
   if (gray || cinfo.num_components == 1)
   {
@@ -1411,7 +1373,7 @@ image_load_jpeg(image_t *img,	/* I - Image pointer */
 		   file_rlookup(img->filename));
     return (-1);
   }
-  else             
+  else
   {
     cinfo.out_color_space      = JCS_RGB;
     cinfo.out_color_components = 3;
@@ -1420,9 +1382,9 @@ image_load_jpeg(image_t *img,	/* I - Image pointer */
 
   jpeg_calc_output_dimensions(&cinfo);
 
-  img->width  = cinfo.output_width;
-  img->height = cinfo.output_height;
-  img->depth  = cinfo.output_components;
+  img->width  = (int)cinfo.output_width;
+  img->height = (int)cinfo.output_height;
+  img->depth  = (int)cinfo.output_components;
 
   if (!load_data)
   {
@@ -1430,7 +1392,7 @@ image_load_jpeg(image_t *img,	/* I - Image pointer */
     return (0);
   }
 
-  img->pixels = (uchar *)malloc(img->width * img->height * img->depth);
+  img->pixels = (uchar *)malloc((size_t)(img->width * img->height * img->depth));
 
   if (img->pixels == NULL)
   {
@@ -1442,9 +1404,7 @@ image_load_jpeg(image_t *img,	/* I - Image pointer */
 
   while (cinfo.output_scanline < cinfo.output_height)
   {
-    row = (JSAMPROW)(img->pixels +
-                     cinfo.output_scanline * cinfo.output_width *
-                     cinfo.output_components);
+    row = (JSAMPROW)(img->pixels + (size_t)cinfo.output_scanline * (size_t)cinfo.output_width * (size_t)cinfo.output_components);
     jpeg_read_scanlines(&cinfo, &row, (JDIMENSION)1);
   }
 
@@ -1472,6 +1432,8 @@ image_load_png(image_t *img,	/* I - Image pointer */
   png_bytep	*rows;		/* PNG row pointers */
   uchar		*inptr,		/* Input pixels */
 		*outptr;	/* Output pixels */
+  int		color_type,	/* PNG color mode */
+		bit_depth;	/* PNG bit depth */
 
 
  /*
@@ -1499,7 +1461,7 @@ image_load_png(image_t *img,	/* I - Image pointer */
 
   rows = NULL;
 
-  if (setjmp(pp->jmpbuf)) 
+  if (setjmp(png_jmpbuf(pp)))
   {
     progress_error(HD_ERROR_BAD_FORMAT, "PNG file contains errors!");
 
@@ -1526,24 +1488,38 @@ image_load_png(image_t *img,	/* I - Image pointer */
 
   png_read_info(pp, info);
 
-  if (info->color_type & PNG_COLOR_MASK_PALETTE)
+  bit_depth  = png_get_bit_depth(pp, info);
+  color_type = png_get_color_type(pp, info);
+
+  if (png_get_valid(pp, info, PNG_INFO_tRNS))
   {
-    png_set_expand(pp);
+    png_set_tRNS_to_alpha(pp);
+    color_type |= PNG_COLOR_MASK_ALPHA;
+  }
+
+  if (color_type & PNG_COLOR_MASK_PALETTE)
+  {
+    png_set_palette_to_rgb(pp);
 
     // If we are writing an encrypted PDF file, bump the use count so we create
     // an image object (Acrobat 6 bug workaround)
     if (Encryption)
       img->use ++;
   }
-  else if (info->bit_depth < 8)
+  else if (!(color_type & PNG_COLOR_MASK_COLOR) && bit_depth < 8)
   {
-    png_set_packing(pp);
-    png_set_expand(pp);
+    png_set_expand_gray_1_2_4_to_8(pp);
   }
-  else if (info->bit_depth == 16)
+  else if (bit_depth == 16)
+  {
+#if PNG_LIBPNG_VER >= 10504
+    png_set_scale_16(pp);
+#else
     png_set_strip_16(pp);
+#endif // PNG_LIBPNG_VER >= 10504
+  }
 
-  if (info->color_type & PNG_COLOR_MASK_COLOR)
+  if (color_type & PNG_COLOR_MASK_COLOR)
   {
     depth      = 3;
     img->depth = gray ? 1 : 3;
@@ -1554,10 +1530,10 @@ image_load_png(image_t *img,	/* I - Image pointer */
     img->depth = 1;
   }
 
-  img->width  = info->width;
-  img->height = info->height;
+  img->width  = (int)png_get_image_width(pp, info);
+  img->height = (int)png_get_image_height(pp, info);
 
-  if ((info->color_type & PNG_COLOR_MASK_ALPHA) || info->num_trans)
+  if (color_type & PNG_COLOR_MASK_ALPHA)
   {
     if ((PSLevel == 0 && PDFVersion >= 14) || PSLevel == 3)
       image_need_mask(img, 8);
@@ -1570,15 +1546,14 @@ image_load_png(image_t *img,	/* I - Image pointer */
   }
 
 #ifdef DEBUG
-  printf("color_type=0x%04x, depth=%d, img->width=%d, img->height=%d, img->depth=%d\n",
-         info->color_type, depth, img->width, img->height, img->depth);
-  if (info->color_type & PNG_COLOR_MASK_COLOR)
+  printf("bit_depth=%d, color_type=0x%04x, depth=%d, img->width=%d, img->height=%d, img->depth=%d\n", bit_depth, color_type, depth, img->width, img->height, img->depth);
+  if (color_type & PNG_COLOR_MASK_COLOR)
     puts("    COLOR");
   else
     puts("    GRAYSCALE");
-  if ((info->color_type & PNG_COLOR_MASK_ALPHA) || info->num_trans)
+  if (color_type & PNG_COLOR_MASK_ALPHA)
     puts("    ALPHA");
-  if (info->color_type & PNG_COLOR_MASK_PALETTE)
+  if (color_type & PNG_COLOR_MASK_PALETTE)
     puts("    PALETTE");
 #endif // DEBUG
 
@@ -1588,15 +1563,15 @@ image_load_png(image_t *img,	/* I - Image pointer */
     return (0);
   }
 
-  img->pixels = (uchar *)malloc(img->width * img->height * depth);
+  img->pixels = (uchar *)calloc(1,(size_t)(img->width * img->height * depth));
 
  /*
   * Allocate pointers...
   */
 
-  rows = (png_bytep *)calloc(info->height, sizeof(png_bytep));
+  rows = (png_bytep *)calloc(png_get_image_height(pp, info), sizeof(png_bytep));
 
-  for (i = 0; i < (int)info->height; i ++)
+  for (i = 0; i < (int)png_get_image_height(pp, info); i ++)
     rows[i] = img->pixels + i * img->width * depth;
 
  /*
@@ -1604,13 +1579,13 @@ image_load_png(image_t *img,	/* I - Image pointer */
   */
 
   for (i = png_set_interlace_handling(pp); i > 0; i --)
-    png_read_rows(pp, rows, NULL, img->height);
+    png_read_rows(pp, rows, NULL, (png_uint_32)img->height);
 
  /*
   * Generate the alpha mask as necessary...
   */
 
-  if ((info->color_type & PNG_COLOR_MASK_ALPHA) || info->num_trans)
+  if (color_type & PNG_COLOR_MASK_ALPHA)
   {
 #ifdef DEBUG
     for (inptr = img->pixels, i = 0; i < img->height; i ++)
@@ -1639,10 +1614,10 @@ image_load_png(image_t *img,	/* I - Image pointer */
   * Reformat the data as necessary for the reader...
   */
 
-  if (gray && info->color_type & PNG_COLOR_MASK_COLOR)
+  if (gray && (color_type & PNG_COLOR_MASK_COLOR))
   {
    /*
-    * Greyscale output needed...
+    * Grayscale output needed...
     */
 
     for (inptr = img->pixels, outptr = img->pixels, i = img->width * img->height;
@@ -1694,16 +1669,16 @@ image_load_png(image_t *img,	/* I - Image pointer */
  */
 
 static void
-image_need_mask(image_t *img,	/* I - Image to add mask to */
-                int     scaling)/* I - Scaling for mask image */
+image_need_mask(image_t *img,		/* I - Image to add mask to */
+                int     scaling)	/* I - Scaling for mask image */
 {
-  int	size;			/* Byte size of mask image */
+  size_t	size;			/* Byte size of mask image */
 
 
   if (img == NULL || img->mask != NULL)
     return;
 
- /* 
+ /*
   * Figure out the size of the mask image, and then allocate and set all the
   * bits needed...
   */
@@ -1714,13 +1689,13 @@ image_need_mask(image_t *img,	/* I - Image to add mask to */
   {
     // Alpha image
     img->maskwidth = img->width;
-    size           = img->width * img->height;
+    size           = (size_t)(img->width * img->height);
   }
   else
   {
     // Alpha mask
     img->maskwidth = (img->width * scaling + 7) / 8;
-    size           = img->maskwidth * img->height * scaling;
+    size           = (size_t)(img->maskwidth * img->height * scaling + 1);
   }
 
   img->mask = (uchar *)calloc(size, 1);
@@ -1829,10 +1804,10 @@ read_word(FILE *fp)       /* I - File to read from */
 {
   unsigned char b0, b1; /* Bytes from file */
 
-  b0 = getc(fp);
-  b1 = getc(fp);
+  b0 = (uchar)getc(fp);
+  b1 = (uchar)getc(fp);
 
-  return ((b1 << 8) | b0);
+  return (unsigned short)((b1 << 8) | b0);
 }
 
 
@@ -1845,12 +1820,12 @@ read_dword(FILE *fp)              /* I - File to read from */
 {
   unsigned char b0, b1, b2, b3; /* Bytes from file */
 
-  b0 = getc(fp);
-  b1 = getc(fp);
-  b2 = getc(fp);
-  b3 = getc(fp);
+  b0 = (uchar)getc(fp);
+  b1 = (uchar)getc(fp);
+  b2 = (uchar)getc(fp);
+  b3 = (uchar)getc(fp);
 
-  return ((((((b3 << 8) | b2) << 8) | b1) << 8) | b0);
+  return (unsigned)((((((b3 << 8) | b2) << 8) | b1) << 8) | b0);
 }
 
 
@@ -1863,15 +1838,10 @@ read_long(FILE *fp)               /* I - File to read from */
 {
   unsigned char b0, b1, b2, b3; /* Bytes from file */
 
-  b0 = getc(fp);
-  b1 = getc(fp);
-  b2 = getc(fp);
-  b3 = getc(fp);
+  b0 = (uchar)getc(fp);
+  b1 = (uchar)getc(fp);
+  b2 = (uchar)getc(fp);
+  b3 = (uchar)getc(fp);
 
   return ((int)(((((b3 << 8) | b2) << 8) | b1) << 8) | b0);
 }
-
-
-/*
- * End of "$Id: image.cxx 1488 2006-05-31 19:00:02Z mike $".
- */
